@@ -61,7 +61,9 @@ class Command(BaseCommand):
         points = self.get_points(document)
         route_name = self.get_route_name(document)
 
-        max_date = None
+        max_date = LocationSnapshot.objects\
+                .filter(source=source)\
+                .aggregate(max_date=Max('date'))['max_date']
         for key_name, data_point in points.items():
             if key_name not in source.data['known_points'].keys():
                 logger.debug("%s not in %s" % (
